Discover Packages
github.com/akvartz/loadout
internal
state
package
Version:
v0.0.0-...-c68aebb
Opens a new window with list of versions in this module.
Published: May 22, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Meta struct {
SchemaVersion int `toml:"schema_version"`
CapturedAt time .Time `toml:"captured_at"`
Hostname string `toml:"hostname"`
OS string `toml:"os"`
}
type SourceState struct {
Packages []string `toml:"packages"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.